==> mule-module-spring-config-4.4.0-sources.jar: org/mule/runtime/config/internal/dsl/spring/CreateComponentBeanDefinitionRequest.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.dsl.spring;

import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.config.internal.dsl.model.SpringComponentModel;
import org.mule.runtime.dsl.api.component.ComponentBuildingDefinition;

import java.util.List;
import java.util.function.Consumer;

public class CreateComponentBeanDefinitionRequest extends CreateBeanDefinitionRequest {

  private final Consumer<ComponentAst> nestedComponentParamProcessor;

  public CreateComponentBeanDefinitionRequest(List<ComponentAst> componentHierarchy,
                                              ComponentAst component,
                                              List<SpringComponentModel> paramsModels,
                                              ComponentBuildingDefinition componentBuildingDefinition,
                                              Consumer<ComponentAst> nestedComponentParamProcessor) {
    super(componentHierarchy, component, paramsModels, componentBuildingDefinition, component.getIdentifier());
    this.nestedComponentParamProcessor = nestedComponentParamProcessor;
  }

  @Override
  public ComponentAst resolveConfigurationComponent() {
    return getComponent();
  }

  public Consumer<ComponentAst> getNestedComponentParamProcessor() {
    return nestedComponentParamProcessor;
  }
}

==> mule-module-spring-config-4.8.4-20250121.035341-4-sources.jar: org/mule/runtime/config/internal/dsl/spring/CreateComponentBeanDefinitionRequest.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.runtime.config.internal.dsl.spring;

import org.mule.runtime.ast.api.ComponentAst;
import org.mule.runtime.config.internal.dsl.model.SpringComponentModel;
import org.mule.runtime.dsl.api.component.ComponentBuildingDefinition;

import java.util.List;
import java.util.function.Consumer;

public class CreateComponentBeanDefinitionRequest extends CreateBeanDefinitionRequest {

  private final Consumer<ComponentAst> nestedComponentParamProcessor;
  private final boolean parentMapType;

  public CreateComponentBeanDefinitionRequest(List<ComponentAst> componentHierarchy,
                                              ComponentAst component,
                                              List<SpringComponentModel> paramsModels,
                                              ComponentBuildingDefinition componentBuildingDefinition,
                                              Consumer<ComponentAst> nestedComponentParamProcessor,
                                              boolean parentMapType) {
    super(componentHierarchy, component, paramsModels, componentBuildingDefinition, component.getIdentifier());
    this.nestedComponentParamProcessor = nestedComponentParamProcessor;
    this.parentMapType = parentMapType;
  }

  @Override
  public ComponentAst resolveConfigurationComponent() {
    return getComponent();
  }

  public Consumer<ComponentAst> getNestedComponentParamProcessor() {
    return nestedComponentParamProcessor;
  }

  public boolean isParentMapType() {
    return parentMapType;
  }

  @Override
  public String toString() {
    return "component request for `" + getComponent().toString();
  }
}
